@@ -184,6 +184,7 @@ void
 set_buffer_names (Buffer * bp, const char *filename)
 {
   astr as = NULL;
+  const char *oldname;
 
   if (filename[0] != '/')
     {
@@ -196,10 +197,11 @@ set_buffer_names (Buffer * bp, const char *filename)
   else
     set_buffer_filename (bp, filename);
 
-  free ((char *) bp->name);
+  oldname = bp->name;
   bp->name = make_buffer_name (filename);
   if (as)
     astr_delete (as);
+  free ((char *) oldname);
 }
 
 /*
@@ -220,8 +222,9 @@ find_buffer (const char *name)
   return NULL;
 }
 
-/* Move the selected buffer to head.  */
-
+/*
+ * Move the selected buffer to head.
+ */
 static void
 move_buffer_to_head (Buffer * bp)
 {
@@ -364,28 +367,15 @@ delete_region (const Region * rp)
 bool
 in_region (size_t lineno, size_t x, Region * rp)
 {
-  if (lineno >= rp->start.n && lineno <= rp->end.n)
-    {
-      if (rp->start.n == rp->end.n)
-        {
-          if (x >= rp->start.o && x < rp->end.o)
-            return true;
-        }
-      else if (lineno == rp->start.n)
-        {
-          if (x >= rp->start.o)
-            return true;
-        }
-      else if (lineno == rp->end.n)
-        {
-          if (x < rp->end.o)
-            return true;
-        }
-      else
-        return true;
-    }
-
-  return false;
+  if (lineno < rp->start.n || lineno > rp->end.n)
+    return false;
+  else if (rp->start.n == rp->end.n)
+    return x >= rp->start.o && x < rp->end.o;
+  else if (lineno == rp->start.n)
+    return x >= rp->start.o;
+  else if (lineno == rp->end.n)
+    return x < rp->end.o;
+  return true;
 }
 
 /*
@@ -467,9 +457,7 @@ deactivate_mark (void)
 size_t
 tab_width (Buffer * bp)
 {
-  size_t t = get_variable_number_bp (bp, "tab-width");
-
-  return t ? t : 1;
+  return MAX (get_variable_number_bp (bp, "tab-width"), 1);
 }
 
 /*
