@@ -31,7 +31,7 @@
 #include "extern.h"
 
 static History *files_history = NULL;
-char *minibuf_contents = NULL;
+static char *minibuf_contents = NULL;
 
 /*--------------------------------------------------------------------------
  * Minibuffer wrapper functions.
@@ -43,16 +43,19 @@ init_minibuf (void)
   files_history = history_new ();
 }
 
-static void
-minibuf_vwrite (const char *fmt, va_list ap)
+int
+minibuf_no_error (void)
 {
-  free (minibuf_contents);
-
-  xvasprintf (&minibuf_contents, fmt, ap);
+  return minibuf_contents == NULL;
+}
 
+void
+minibuf_refresh (void)
+{
   if (cur_wp)
     {
-      term_minibuf_write (minibuf_contents);
+      if (minibuf_contents)
+        term_minibuf_write (minibuf_contents);
 
       /* Redisplay (and leave the cursor in the correct position). */
       term_redisplay ();
@@ -60,6 +63,14 @@ minibuf_vwrite (const char *fmt, va_list ap)
     }
 }
 
+static void
+minibuf_vwrite (const char *fmt, va_list ap)
+{
+  free (minibuf_contents);
+  xvasprintf (&minibuf_contents, fmt, ap);
+  minibuf_refresh ();
+}
+
 /*
  * Write the specified string in the minibuffer.
  */
@@ -140,6 +151,7 @@ minibuf_read_number (const char *fmt, ...)
     }
   while (n == ULONG_MAX);
 
+  free (buf);
   return n;
 }
 
@@ -203,12 +215,13 @@ minibuf_read_yn (const char *fmt, ...)
 {
   va_list ap;
   char *buf, *errmsg = "";
+  int ret;
 
   va_start (ap, fmt);
   xvasprintf (&buf, fmt, ap);
   va_end (ap);
 
-  for (;;) {
+  for (ret = -2; ret == -2;) {
     size_t key;
 
     minibuf_write ("%s%s", errmsg, buf);
@@ -216,15 +229,21 @@ minibuf_read_yn (const char *fmt, ...)
     switch (key)
       {
       case 'y':
-        return true;
+        ret = true;
+        break;
       case 'n':
-        return false;
+        ret = false;
+        break;
       case KBD_CTRL | 'g':
-        return -1;
+        ret = -1;
+        break;
       default:
         errmsg = "Please answer y or n.  ";
       }
   }
+
+  free (buf);
+  return ret;
 }
 
 int
@@ -341,5 +360,5 @@ minibuf_vread_completion (const char *fmt, char *value, Completion * cp,
 void
 minibuf_clear (void)
 {
-  term_minibuf_write ("");
+  minibuf_write ("");
 }
